==> vue-layout-builder-0.0.1.tgz: package/tests/unit/components/LayoutBuilderEmptyState.spec.js <==
import { shallowMount } from "@vue/test-utils";
import EmptyState from "../../../src/components/LayoutBuilderEmptyState.vue";

describe("EmptyState.vue", () => {
  describe("not passing props.label", () => {
    const wrapper = shallowMount(EmptyState);

    it("doesn't render a label", () => {
      expect(wrapper.text()).toBe("");
    });
  });

  describe("passing props.label", () => {
    const label = "label";
    const wrapper = shallowMount(EmptyState, {
      propsData: {
        label
      }
    });

    it("doesn't render a label", () => {
      expect(wrapper.text()).toBe(label);
    });
  });

  describe("passing props.isButton", () => {
    const wrapper = shallowMount(EmptyState, {
      propsData: {
        isButton: true
      }
    });

    it("renders a button", () => {
      expect(wrapper.element.tagName).toBe("BUTTON");
    });

    it("add a 'EmptyState--button' class", () => {
      expect(wrapper.classes()).toContain("LayoutBuilderEmptyState--button");
    });

    it("triggers a content-edited event when clicking on the component", () => {
      wrapper.trigger("click");
      expect(wrapper.emitted("content-edited")).toBeTruthy();
    });
  });

  describe("not passing props.isButton", () => {
    it("renders a div", () => {
      const wrapper = shallowMount(EmptyState);
      expect(wrapper.element.tagName).toBe("DIV");
    });

    it("doesn't add a 'EmptyState--button' class", () => {
      const wrapper = shallowMount(EmptyState);
      expect(wrapper.classes()).not.toContain(
        "LayoutBuilderEmptyState--button"
      );
    });
  });
});

==> vue-layout-builder-0.0.3.tgz: package/tests/unit/components/LayoutBuilderEmptyState.spec.js <==
import { shallowMount } from "@vue/test-utils";
import EmptyState from "../../../src/components/LayoutBuilderEmptyState.vue";

describe("EmptyState.vue", () => {
  describe("not passing props.label", () => {
    const wrapper = shallowMount(EmptyState);

    it("doesn't render a label", () => {
      expect(wrapper.text()).toBe("");
    });
  });

  describe("passing props.label", () => {
    const label = "label";
    const wrapper = shallowMount(EmptyState, {
      propsData: {
        label
      }
    });

    it("doesn't render a label", () => {
      expect(wrapper.text()).toBe(label);
    });
  });

  describe("passing props.isButton", () => {
    const wrapper = shallowMount(EmptyState, {
      propsData: {
        isButton: true
      }
    });

    it("renders a button", () => {
      expect(wrapper.element.tagName).toBe("BUTTON");
    });

    it("add a 'EmptyState--button' class", () => {
      expect(wrapper.classes()).toContain("LayoutBuilderEmptyState--button");
    });

    it("triggers a add-content-clicked event when clicking on the component", () => {
      wrapper.trigger("click");
      expect(wrapper.emitted("add-content-clicked")).toBeTruthy();
    });
  });

  describe("not passing props.isButton", () => {
    it("renders a div", () => {
      const wrapper = shallowMount(EmptyState);
      expect(wrapper.element.tagName).toBe("DIV");
    });

    it("doesn't add a 'EmptyState--button' class", () => {
      const wrapper = shallowMount(EmptyState);
      expect(wrapper.classes()).not.toContain(
        "LayoutBuilderEmptyState--button"
      );
    });
  });
});
